@@ -13,11 +13,12 @@ from .mappings import Area, NEIGHBOURS, lookup_area
 from .parsers import parse_prices, parse_loads, parse_generation, \
     parse_installed_capacity_per_plant, parse_crossborder_flows, \
     parse_unavailabilities, parse_contracted_reserve, parse_imbalance_prices_zip, \
-    parse_imbalance_volumes_zip, parse_netpositions, parse_procured_balancing_capacity
+    parse_imbalance_volumes_zip, parse_netpositions, parse_procured_balancing_capacity, \
+    parse_water_hydro
 from .decorators import retry, paginated, year_limited, day_limited, documents_limited
 
 __title__ = "entsoe-py"
-__version__ = "0.5.3"
+__version__ = "0.5.4"
 __author__ = "EnergieID.be, Frank Boerman"
 __license__ = "MIT"
 
@@ -408,6 +409,30 @@ class EntsoeRawClient:
         response = self._base_request(params=params, start=start, end=end)
         return response.text
 
+    def query_aggregate_water_reservoirs_and_hydro_storage(self, country_code: Union[Area, str], start: pd.Timestamp,
+            end: pd.Timestamp) -> str:
+        """
+        Parameters
+        ----------
+        country_code : Area|str
+        start : pd.Timestamp
+        end : pd.Timestamp
+        offset : int
+            offset for querying more than 100 documents
+
+        Returns
+        -------
+        str
+        """
+        area = lookup_area(country_code)
+        params = {
+            'documentType': 'A72',
+            'processType': 'A16',
+            'in_Domain': area.code
+        }
+        response = self._base_request(params=params, start=start, end=end)
+        return response.text
+
     def query_crossborder_flows(
             self, country_code_from: Union[Area, str],
             country_code_to: Union[Area, str], start: pd.Timestamp,
@@ -1246,6 +1271,21 @@ class EntsoePandasClient(EntsoeRawClient):
         df = parse_installed_capacity_per_plant(text)
         return df
 
+    @year_limited
+    @paginated
+    def query_aggregate_water_reservoirs_and_hydro_storage(self, country_code: Union[Area, str], start: pd.Timestamp,
+            end: pd.Timestamp) -> pd.DataFrame:
+        area = lookup_area(country_code)
+        text = super(
+            EntsoePandasClient,
+            self).query_aggregate_water_reservoirs_and_hydro_storage(
+            country_code=area, start=start, end=end)
+
+        df = parse_water_hydro(text, area.tz)
+
+        return df
+
+
     @year_limited
     def query_crossborder_flows(
             self, country_code_from: Union[Area, str],
